# DiagAssistAI
![GitHub License](https://img.shields.io/github/license/WilhelmBuitrago/DiagAssistAI)
![Static Badge](https://img.shields.io/badge/Python-3.10.12-blue?logo=python)
<p float="center">
  <img src=".asset/model_p.png?raw=true"/>
</p>

#Installation

GSamNetwork requires `python==3.10.12`, as well as `torch==2.4.0`.

##Enviroment Conda

``
conda crate -n <name> python==3.10.12 && conda activate <name>
``

###Installing torch

``
pip3 install torch torchvision torchaudio --index-url https://download.pytorch.org/whl/cu121
``